=== modified file 'drizzled/join.cc'
--- drizzled/join.cc	2009-05-31 17:49:30 +0000
+++ drizzled/join.cc	2009-05-31 20:30:04 +0000
@@ -40,6 +40,7 @@
 #include "drizzled/lock.h"
 #include "drizzled/nested_join.h"
 #include "drizzled/join.h"
+#include "drizzled/join_cache.h"
 #include "drizzled/show.h"
 #include "drizzled/field/blob.h"
 #include "mysys/my_bit.h"
@@ -457,8 +458,7 @@
   @retval
     1   error
 */
-int
-JOIN::optimize()
+int JOIN::optimize()
 {
   // to prevent double initialization on EXPLAIN
   if (optimized)
@@ -547,9 +547,9 @@
     {
       if (res == HA_ERR_KEY_NOT_FOUND)
       {
-  zero_result_cause= "No matching min/max row";
-  error=0;
-  return(0);
+        zero_result_cause= "No matching min/max row";
+        error=0;
+        return(0);
       }
       if (res > 1)
       {
@@ -686,7 +686,7 @@
   /* Optimize distinct away if possible */
   {
     order_st *org_order= order;
-    order=remove_constants(this, order,conds,1, &simple_order);
+    order= remove_constants(this, order,conds,1, &simple_order);
     if (session->is_error())
     {
       error= 1;
@@ -767,7 +767,7 @@
       GROUP BY query if:
       - The GROUP BY can be done through indexes (no sort) and the order_st
         BY only uses selected fields.
-  (In this case we can later optimize away GROUP BY and order_st BY)
+        (In this case we can later optimize away GROUP BY and order_st BY)
       - We are scanning the whole table without LIMIT
         This can happen if:
         - We are using CALC_FOUND_ROWS
@@ -791,28 +791,28 @@
                                 &tab->table->keys_in_use_for_group_by) != 0);
       count_field_types(select_lex, &tmp_table_param, all_fields, 0);
       if ((skip_group && all_order_fields_used) ||
-    select_limit == HA_POS_ERROR ||
-    (order && !skip_sort_order))
+          select_limit == HA_POS_ERROR ||
+          (order && !skip_sort_order))
       {
-  /*  Change DISTINCT to GROUP BY */
-  select_distinct= 0;
-  no_order= !order;
-  if (all_order_fields_used)
-  {
-    if (order && skip_sort_order)
-    {
-      /*
-        Force MySQL to read the table in sorted order to get result in
-        order_st BY order.
-      */
-      tmp_table_param.quick_group=0;
-    }
-    order=0;
+        /*  Change DISTINCT to GROUP BY */
+        select_distinct= 0;
+        no_order= !order;
+        if (all_order_fields_used)
+        {
+          if (order && skip_sort_order)
+          {
+            /*
+              Force MySQL to read the table in sorted order to get result in
+              order_st BY order.
+            */
+            tmp_table_param.quick_group=0;
+          }
+          order=0;
         }
-  group=1;        // For end_write_group
+        group=1;        // For end_write_group
       }
       else
-  group_list= 0;
+        group_list= 0;
     }
     else if (session->is_fatal_error)     // End of memory
       return(1);
@@ -875,8 +875,7 @@
 
   sj_tmp_tables= NULL;
   if (!select_lex->sj_nests.is_empty())
-    setup_semijoin_dups_elimination(this, select_opts_for_readinfo,
-                                    no_jbuf_after);
+    setup_semijoin_dups_elimination(this, select_opts_for_readinfo, no_jbuf_after);
 
   // No cache for MATCH == 'Don't use join buffering when we use MATCH'.
   if (make_join_readinfo(this, select_opts_for_readinfo, no_jbuf_after))
@@ -897,8 +896,7 @@
     if (!having)
     {
       Item *where= conds;
-      if (join_tab[0].type == JT_EQ_REF &&
-    join_tab[0].ref.items[0]->name == in_left_expr_name)
+      if (join_tab[0].type == JT_EQ_REF && join_tab[0].ref.items[0]->name == in_left_expr_name)
       {
         remove_subq_pushed_predicates(&where);
         save_index_subquery_explain_info(join_tab, where);
@@ -914,7 +912,7 @@
       else if (join_tab[0].type == JT_REF &&
          join_tab[0].ref.items[0]->name == in_left_expr_name)
       {
-  remove_subq_pushed_predicates(&where);
+        remove_subq_pushed_predicates(&where);
         save_index_subquery_explain_info(join_tab, where);
         join_tab[0].type= JT_INDEX_SUBQUERY;
         error= 0;
@@ -927,7 +925,8 @@
                                                                  NULL,
                                                                  0)));
       }
-    } else if (join_tab[0].type == JT_REF_OR_NULL &&
+    } 
+    else if (join_tab[0].type == JT_REF_OR_NULL &&
          join_tab[0].ref.items[0]->name == in_left_expr_name &&
                having->name == in_having_cond)
     {
@@ -1072,8 +1071,7 @@
       If having is not handled here, it will be checked before the row
       is sent to the client.
     */
-    if (tmp_having &&
-  (sort_and_group || (exec_tmp_table1->distinct && !group_list)))
+    if (tmp_having && (sort_and_group || (exec_tmp_table1->distinct && !group_list)))
       having= tmp_having;
 
     /* if group or order on first table, sort first */
@@ -1082,7 +1080,7 @@
       session->set_proc_info("Sorting for group");
       if (create_sort_index(session, this, group_list,
           HA_POS_ERROR, HA_POS_ERROR, false) ||
-    alloc_group_fields(this, group_list) ||
+          alloc_group_fields(this, group_list) ||
           make_sum_func_list(all_fields, fields_list, 1) ||
           setup_sum_funcs(session, sum_funcs))
       {
@@ -1122,19 +1120,19 @@
       JOIN_TAB *last_join_tab= join_tab+tables-1;
       do
       {
-  if (used_tables & last_join_tab->table->map)
-    break;
-  last_join_tab->not_used_in_distinct=1;
+        if (used_tables & last_join_tab->table->map)
+          break;
+        last_join_tab->not_used_in_distinct=1;
       } while (last_join_tab-- != join_tab);
       /* Optimize "select distinct b from t1 order by key_part_1 limit #" */
       if (order && skip_sort_order)
       {
-  /* Should always succeed */
-  if (test_if_skip_sort_order(&join_tab[const_tables],
-            order, unit->select_limit_cnt, 0,
-                                    &join_tab[const_tables].table->
-                                      keys_in_use_for_order_by))
-    order=0;
+        /* Should always succeed */
+        if (test_if_skip_sort_order(&join_tab[const_tables],
+                  order, unit->select_limit_cnt, 0,
+                                          &join_tab[const_tables].table->
+                                            keys_in_use_for_order_by))
+          order= 0;
       }
     }
 
@@ -1151,7 +1149,6 @@
   return(0);
 }
 
-
 /**
   Restore values in temporary join.
 */
@@ -1160,8 +1157,7 @@
   memcpy(tmp_join, this, (size_t) sizeof(JOIN));
 }
 
-int
-JOIN::reinit()
+int JOIN::reinit()
 {
   unit->offset_limit_cnt= (ha_rows)(select_lex->offset_limit ?
                                     select_lex->offset_limit->val_uint() :
@@ -1213,9 +1209,7 @@
    @retval 0      success.
    @retval 1      error occurred.
 */
-
-bool
-JOIN::init_save_join_tab()
+bool JOIN::init_save_join_tab()
 {
   if (!(tmp_join= (JOIN*)session->alloc(sizeof(JOIN))))
     return 1;                                  /* purecov: inspected */
@@ -1224,9 +1218,7 @@
   return 0;
 }
 
-
-bool
-JOIN::save_join_tab()
+bool JOIN::save_join_tab()
 {
   if (!join_tab_save && select_lex->master_unit()->uncacheable)
   {
@@ -1237,7 +1229,6 @@
   return 0;
 }
 
-
 /**
   Exec select.
 
@@ -1913,6 +1904,7 @@
   }
   return false;
 }
+
 /**
   Partially cleanup JOIN after it has executed: close index or rnd read
   (table cursors), free quick selects.
@@ -2022,7 +2014,6 @@
     With subquery this function definitely will be called several times,
     but even for simple query it can be called several times.
 */
-
 void JOIN::cleanup(bool full)
 {
   if (table)
@@ -2041,14 +2032,14 @@
     if (full)
     {
       for (tab= join_tab, end= tab+tables; tab != end; tab++)
-  tab->cleanup();
+        tab->cleanup();
       table= 0;
     }
     else
     {
       for (tab= join_tab, end= tab+tables; tab != end; tab++)
       {
-  if (tab->table)
+        if (tab->table)
           tab->table->file->ha_index_or_rnd_end();
       }
     }
@@ -2096,7 +2087,7 @@
     must clear only the non-const tables, as const tables
     are not re-calculated.
   */
-  for (uint32_t i=join->const_tables ; i < join->tables ; i++)
+  for (uint32_t i= join->const_tables; i < join->tables; i++)
     join->table[i]->mark_as_null_row();   // All fields are NULL
 }
 
@@ -2148,7 +2139,6 @@
   return(sum_funcs == 0);
 }
 
-
 /**
   Initialize 'sum_funcs' array with all Item_sum objects.
 
@@ -2162,9 +2152,10 @@
   @retval
     1  error
 */
-
-bool JOIN::make_sum_func_list(List<Item> &field_list, List<Item> &send_fields,
-            bool before_group_by, bool recompute)
+bool JOIN::make_sum_func_list(List<Item> &field_list, 
+                              List<Item> &send_fields,
+                              bool before_group_by, 
+                              bool recompute)
 {
   List_iterator_fast<Item> it(field_list);
   Item_sum **func;
@@ -2268,7 +2259,7 @@
             ROLLUP is used together with DISTINCT in the SELECT list.
             Usually when creating temporary tables for a intermidiate
             result we do not include fields for constant expressions.
-    */
+          */
           Item* new_item= new Item_func_rollup_const(item);
           if (!new_item)
             return 1;
@@ -2299,7 +2290,6 @@
   return 0;
 }
 
-
 /**
   Fill up rollup structures with pointers to fields to use.
 
@@ -2315,9 +2305,7 @@
   @retval
     1    on error
 */
-
-bool JOIN::rollup_make_fields(List<Item> &fields_arg, List<Item> &sel_fields,
-            Item_sum ***func)
+bool JOIN::rollup_make_fields(List<Item> &fields_arg, List<Item> &sel_fields, Item_sum ***func)
 {
   List_iterator_fast<Item> it(fields_arg);
   Item *first_field= sel_fields.head();
@@ -2361,18 +2349,16 @@
     sum_funcs_end[pos+1]= *func;
 
     /* Find the start of the group for this level */
-    for (i= 0, start_group= group_list ;
-   i++ < pos ;
-   start_group= start_group->next)
-      ;
+    for (i= 0, start_group= group_list ;i++ < pos ;start_group= start_group->next)
+    {}
 
     it.rewind();
     while ((item= it++))
     {
       if (item == first_field)
       {
-  real_fields= 1;       // End of hidden fields
-  ref_array= ref_array_start;
+        real_fields= 1;       // End of hidden fields
+        ref_array= ref_array_start;
       }
 
       if (item->type() == Item::SUM_FUNC_ITEM && !item->const_item() &&
@@ -2380,41 +2366,41 @@
            ((Item_sum *)item)->depended_from() == select_lex))
 
       {
-  /*
-    This is a top level summary function that must be replaced with
-    a sum function that is reset for this level.
+        /*
+          This is a top level summary function that must be replaced with
+          a sum function that is reset for this level.
 
-    NOTE: This code creates an object which is not that nice in a
-    sub select.  Fortunately it's not common to have rollup in
-    sub selects.
-  */
-  item= item->copy_or_same(session);
-  ((Item_sum*) item)->make_unique();
-  *(*func)= (Item_sum*) item;
-  (*func)++;
+          NOTE: This code creates an object which is not that nice in a
+          sub select.  Fortunately it's not common to have rollup in
+          sub selects.
+        */
+        item= item->copy_or_same(session);
+        ((Item_sum*) item)->make_unique();
+        *(*func)= (Item_sum*) item;
+        (*func)++;
       }
       else
       {
-  /* Check if this is something that is part of this group by */
-  order_st *group_tmp;
-  for (group_tmp= start_group, i= pos ;
-             group_tmp ; group_tmp= group_tmp->next, i++)
-  {
-          if (*group_tmp->item == item)
-    {
-      /*
-        This is an element that is used by the GROUP BY and should be
-        set to NULL in this level
-      */
-            Item_null_result *null_item= new (session->mem_root) Item_null_result();
-            if (!null_item)
-              return 1;
-      item->maybe_null= 1;    // Value will be null sometimes
-            null_item->result_field= item->get_tmp_table_field();
-            item= null_item;
-      break;
-    }
-  }
+        /* Check if this is something that is part of this group by */
+        order_st *group_tmp;
+        for (group_tmp= start_group, i= pos ;
+                  group_tmp ; group_tmp= group_tmp->next, i++)
+        {
+                if (*group_tmp->item == item)
+          {
+            /*
+              This is an element that is used by the GROUP BY and should be
+              set to NULL in this level
+            */
+                  Item_null_result *null_item= new (session->mem_root) Item_null_result();
+                  if (!null_item)
+                    return 1;
+            item->maybe_null= 1;    // Value will be null sometimes
+                  null_item->result_field= item->get_tmp_table_field();
+                  item= null_item;
+            break;
+          }
+        }
       }
       *ref_array= item;
       if (real_fields)
@@ -2449,7 +2435,6 @@
   @retval
     1   If send_data_failed()
 */
-
 int JOIN::rollup_send_data(uint32_t idx)
 {
   uint32_t i;
@@ -2490,7 +2475,6 @@
   @retval
     1   if write_data_failed()
 */
-
 int JOIN::rollup_write_data(uint32_t idx, Table *table_arg)
 {
   uint32_t i;
@@ -2529,7 +2513,6 @@
   clear results if there are not rows found for group
   (end_send_group/end_write_group)
 */
-
 void JOIN::clear()
 {
   clear_tables(this);
@@ -2542,6 +2525,7 @@
       func->clear();
   }
 }
+
 /**
   change select_result object of JOIN.
 
@@ -2577,9 +2561,7 @@
 */
 bool error_if_full_join(JOIN *join)
 {
-  for (JOIN_TAB *tab=join->join_tab, *end=join->join_tab+join->tables;
-       tab < end;
-       tab++)
+  for (JOIN_TAB *tab= join->join_tab, *end= join->join_tab+join->tables; tab < end; tab++)
   {
     if (tab->type == JT_ALL && (!tab->select || !tab->select->quick))
     {
@@ -2591,17 +2573,21 @@
   return(0);
 }
 
-/*
+/**
+  @brief
+  
   Process one record of the nested loop join.
 
-    This function will evaluate parts of WHERE/ON clauses that are
-    applicable to the partial record on hand and in case of success
-    submit this record to the next level of the nested loop.
+  @details 
+
+  This function will evaluate parts of WHERE/ON clauses that are
+  applicable to the partial record on hand and in case of success
+  submit this record to the next level of the nested loop.
 */
 enum_nested_loop_state evaluate_join_record(JOIN *join, JOIN_TAB *join_tab, int error)
 {
-  bool not_used_in_distinct=join_tab->not_used_in_distinct;
-  ha_rows found_records=join->found_records;
+  bool not_used_in_distinct= join_tab->not_used_in_distinct;
+  ha_rows found_records= join->found_records;
   COND *select_cond= join_tab->select_cond;
 
   if (error > 0 || (join->session->is_error()))     // Fatal error
@@ -2794,7 +2780,7 @@
   return (*join_tab->next_select)(join, join_tab+1, 0);
 }
 
-enum_nested_loop_state flush_cached_records(JOIN *join,JOIN_TAB *join_tab,bool skip_last)
+enum_nested_loop_state flush_cached_records(JOIN *join, JOIN_TAB *join_tab, bool skip_last)
 {
   enum_nested_loop_state rc= NESTED_LOOP_OK;
   int error;

=== modified file 'drizzled/join_cache.cc'
--- drizzled/join_cache.cc	2009-05-31 18:45:00 +0000
+++ drizzled/join_cache.cc	2009-05-31 20:30:04 +0000
@@ -51,7 +51,7 @@
   last record is stored with pointers to blobs to support very big
   records
 ******************************************************************************/
-int join_init_cache(Session *session,JOIN_TAB *tables,uint32_t table_count)
+int join_init_cache(Session *session, JOIN_TAB *tables, uint32_t table_count)
 {
   register unsigned int i;
   unsigned int length, blobs;
@@ -63,7 +63,7 @@
   cache= &tables[table_count].cache;
   cache->fields=blobs=0;
 
-  join_tab=tables;
+  join_tab= tables;
   for (i=0 ; i < table_count ; i++,join_tab++)
   {
     if (!join_tab->used_fieldlength)		/* Not calced yet */
@@ -96,9 +96,7 @@
   {
     uint32_t null_fields=0, used_fields;
     Field **f_ptr,*field;
-    for (f_ptr=tables[i].table->field,used_fields=tables[i].used_fields ;
-	 used_fields ;
-	 f_ptr++)
+    for (f_ptr= tables[i].table->field,used_fields= tables[i].used_fields; used_fields; f_ptr++)
     {
       field= *f_ptr;
       if (field->isReadSet())
@@ -109,7 +107,7 @@
           (*blob_ptr++)=copy;
         if (field->maybe_null())
           null_fields++;
-              copy->get_rowid= NULL;
+        copy->get_rowid= NULL;
         copy++;
       }
     }
@@ -150,20 +148,19 @@
         /* We will need to call h->position(): */
         copy->get_rowid= tables[i].table;
         /* And those after us won't have to: */
-        tables[i].rowid_keep_flags &=  ~((int)JOIN_TAB::CALL_POSITION);
+        tables[i].rowid_keep_flags&=  ~((int)JOIN_TAB::CALL_POSITION);
       }
       copy++;
     }
   }
 
-  cache->length=length+blobs*sizeof(char*);
-  cache->blobs=blobs;
+  cache->length= length+blobs*sizeof(char*);
+  cache->blobs= blobs;
   *blob_ptr= NULL;					/* End sequentel */
-  size= cmax((size_t)session->variables.join_buff_size,
-            (size_t)cache->length);
-  if (!(cache->buff=(unsigned char*) malloc(size)))
+  size= cmax((size_t) session->variables.join_buff_size, (size_t)cache->length);
+  if (!(cache->buff= (unsigned char*) malloc(size)))
     return 1;				/* Don't use cache */ /* purecov: inspected */
-  cache->end=cache->buff+size;
+  cache->end= cache->buff+size;
   reset_cache_write(cache);
   return 0;
 }
@@ -175,34 +172,33 @@
   CACHE_FIELD *copy,*end_field;
   bool last_record;
 
-  pos=cache->pos;
-  end_field=cache->field+cache->fields;
+  pos= cache->pos;
+  end_field= cache->field+cache->fields;
 
-  length=cache->length;
+  length= cache->length;
   if (cache->blobs)
     length+= used_blob_length(cache->blob_ptr);
   if ((last_record= (length + cache->length > (size_t) (cache->end - pos))))
-    cache->ptr_record=cache->records;
+    cache->ptr_record= cache->records;
   /*
     There is room in cache. Put record there
   */
   cache->records++;
-  for (copy=cache->field ; copy < end_field; copy++)
+  for (copy= cache->field; copy < end_field; copy++)
   {
     if (copy->blob_field)
     {
       if (last_record)
       {
-        copy->blob_field->get_image(pos, copy->length+sizeof(char*),
-                  copy->blob_field->charset());
-        pos+=copy->length+sizeof(char*);
+        copy->blob_field->get_image(pos, copy->length+sizeof(char*), copy->blob_field->charset());
+        pos+= copy->length+sizeof(char*);
       }
       else
       {
         copy->blob_field->get_image(pos, copy->length, // blob length
 				    copy->blob_field->charset());
         memcpy(pos+copy->length,copy->str,copy->blob_length);  // Blob data
-        pos+=copy->length+copy->blob_length;
+        pos+= copy->length+copy->blob_length;
       }
     }
     else
@@ -214,10 +210,9 @@
       if (copy->strip)
       {
         unsigned char *str,*end;
-        for (str=copy->str,end= str+copy->length;
-            end > str && end[-1] == ' ' ;
-            end--) ;
-        length=(uint32_t) (end-str);
+        for (str= copy->str,end= str+copy->length; end > str && end[-1] == ' '; end--)
+        {}
+        length= (uint32_t) (end-str);
         memcpy(pos+2, str, length);
         int2store(pos, length);
         pos+= length+2;
@@ -225,18 +220,18 @@
       else
       {
         memcpy(pos,copy->str,copy->length);
-        pos+=copy->length;
+        pos+= copy->length;
       }
     }
   }
-  cache->pos=pos;
+  cache->pos= pos;
   return last_record || (size_t) (cache->end - pos) < cache->length;
 }
 
 void reset_cache_read(JOIN_CACHE *cache)
 {
-  cache->record_nr=0;
-  cache->pos=cache->buff;
+  cache->record_nr= 0;
+  cache->pos= cache->buff;
 }
 
 void reset_cache_write(JOIN_CACHE *cache)

=== modified file 'drizzled/join_cache.h'
--- drizzled/join_cache.h	2009-05-31 18:42:38 +0000
+++ drizzled/join_cache.h	2009-05-31 20:30:04 +0000
@@ -67,8 +67,8 @@
 } JOIN_CACHE;
 
 int join_init_cache(Session *session, JOIN_TAB *tables, uint32_t table_count);
-bool store_record_in_cache(JOIN_CACHE *cache);
 void reset_cache_read(JOIN_CACHE *cache);
 void reset_cache_write(JOIN_CACHE *cache);
+bool store_record_in_cache(JOIN_CACHE *cache);
 
 #endif /* DRIZZLED_JOIN_CACHE_H */

=== modified file 'drizzled/join_tab.h'
--- drizzled/join_tab.h	2009-05-31 19:01:49 +0000
+++ drizzled/join_tab.h	2009-05-31 20:30:04 +0000
@@ -28,12 +28,13 @@
 #ifndef DRIZZLED_JOIN_TAB_H
 #define DRIZZLED_JOIN_TAB_H
 
-typedef struct st_join_table {
+typedef struct st_join_table 
+{
   st_join_table() {}                          /* Remove gcc warning */
-  Table		*table;
-  KEYUSE	*keyuse;			/**< pointer to first used key */
-  SQL_SELECT	*select;
-  COND		*select_cond;
+  Table *table;
+  KEYUSE *keyuse;			/**< pointer to first used key */
+  SQL_SELECT *select;
+  COND *select_cond;
   QUICK_SELECT_I *quick;
   /*
     The value of select_cond before we've attempted to do Index Condition
@@ -42,23 +43,23 @@
     scenarios).
     NULL means no index condition pushdown was performed.
   */
-  Item          *pre_idx_push_select_cond;
-  Item	       **on_expr_ref;   /**< pointer to the associated on expression   */
-  COND_EQUAL    *cond_equal;    /**< multiple equalities for the on expression */
+  Item *pre_idx_push_select_cond;
+  Item **on_expr_ref;   /**< pointer to the associated on expression   */
+  COND_EQUAL *cond_equal;    /**< multiple equalities for the on expression */
   st_join_table *first_inner;   /**< first inner table for including outerjoin */
-  bool           found;         /**< true after all matches or null complement */
-  bool           not_null_compl;/**< true before null complement is added      */
+  bool found;         /**< true after all matches or null complement */
+  bool not_null_compl;/**< true before null complement is added      */
   st_join_table *last_inner;    /**< last table table for embedding outer join */
   st_join_table *first_upper;  /**< first inner table for embedding outer join */
   st_join_table *first_unmatched; /**< used for optimization purposes only     */
 
   /* Special content for EXPLAIN 'Extra' column or NULL if none */
-  const char	*info;
+  const char *info;
   /*
     Bitmap of TAB_INFO_* bits that encodes special line for EXPLAIN 'Extra'
     column, or 0 if there is no info.
   */
-  uint32_t          packed_info;
+  uint32_t packed_info;
 
   Read_record_func read_first_record;
   Next_select_func next_select;
@@ -70,11 +71,11 @@
   */
   Read_record_func save_read_first_record;/* to save read_first_record */
   int (*save_read_record) (READ_RECORD *);/* to save read_record.read_record */
-  double	worst_seeks;
+  double worst_seeks;
   key_map	const_keys;			/**< Keys with constant part */
   key_map	checked_keys;			/**< Keys checked in find_best */
   key_map	needed_reg;
-  key_map       keys;                           /**< all keys with can be used */
+  key_map keys;                           /**< all keys with can be used */
 
   /* Either #rows in the table or 1 for const table.  */
   ha_rows	records;
@@ -82,17 +83,17 @@
     Number of records that will be scanned (yes scanned, not returned) by the
     best 'independent' access method, i.e. table scan or QUICK_*_SELECT)
   */
-  ha_rows       found_records;
+  ha_rows found_records;
   /*
     Cost of accessing the table using "ALL" or range/index_merge access
     method (but not 'index' for some reason), i.e. this matches method which
     E(#records) is in found_records.
   */
-  ha_rows       read_time;
+  ha_rows read_time;
 
   table_map	dependent,key_dependent;
-  uint		use_quick,index;
-  uint		status;				///< Save status for cache
+  uint32_t use_quick,index;
+  uint32_t status;				///< Save status for cache
   uint		used_fields,used_fieldlength,used_blobs;
   enum join_type type;
   bool		cached_eq_ref_table,eq_ref_table,not_used_in_distinct;
@@ -103,10 +104,10 @@
     scan has been chosen to access the table data and we expect to scan
     this number of rows for the table.
   */
-  ha_rows       limit;
+  ha_rows limit;
   TABLE_REF	ref;
-  JOIN_CACHE	cache;
-  JOIN		*join;
+  JOIN_CACHE cache;
+  JOIN *join;
   /** Bitmap of nested joins this table is part of */
 
   /* SemiJoinDuplicateElimination variables: */
@@ -114,12 +115,12 @@
     Embedding SJ-nest (may be not the direct parent), or NULL if none.
     This variable holds the result of table pullout.
   */
-  TableList    *emb_sj_nest;
+  TableList *emb_sj_nest;
 
   /* Variables for semi-join duplicate elimination */
-  SJ_TMP_TABLE  *flush_weedout_table;
-  SJ_TMP_TABLE  *check_weed_out_table;
-  struct st_join_table  *do_firstmatch;
+  SJ_TMP_TABLE *flush_weedout_table;
+  SJ_TMP_TABLE *check_weed_out_table;
+  struct st_join_table *do_firstmatch;
 
   /*
      ptr  - this join tab should do an InsideOut scan. Points
@@ -145,8 +146,7 @@
     CALL_POSITION=2
   };
   /* A set of flags from the above enum */
-  int  rowid_keep_flags;
-
+  int rowid_keep_flags;
 
   /* NestedOuterJoins: Bitmap of nested joins this table is part of */
   nested_join_map embedding_map;

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2009-05-31 19:33:00 +0000
+++ drizzled/sql_select.cc	2009-05-31 20:30:04 +0000
@@ -4562,7 +4562,7 @@
   }
   if (join_tab->use_quick != 2 || test_if_quick_select(join_tab) <= 0)
   {
-    if (!store_record_in_cache(&join_tab->cache))
+    if (! store_record_in_cache(&join_tab->cache))
       return NESTED_LOOP_OK;                     // There is more room in cache
     return flush_cached_records(join,join_tab,false);
   }

